package uspf

  1. Overview
  2. Docs

Module Uspf.RecordSource

Sourcetype t
Sourceval v : (qualifier * mechanism) list -> modifier list -> t

record ms [] returns a record which can be serialized into the zone file of a specific domain-name as the sender policy.

Sourceval to_string : t -> string

record_to_string v returns the serialized version of the record to be able to save it into the zone file of a domain-name as the sender policy.

Sourceval of_string : ctx:ctx -> string -> (t, [> `Msg of string ]) result

record_of_string ~ctx str tries to parse and expand macro of the given string which should come from the TXT record of a domain-name as the sender policy of this domain-name.

Sourceval pp : t Fmt.t
Sourceval equal : t -> t -> bool