package uspf
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Module Uspf.RecordSource
record ms [] returns a record which can be serialized into the zone file of a specific domain-name as the sender policy.
record_to_string v returns the serialized version of the record to be able to save it into the zone file of a domain-name as the sender policy.
record_of_string ~ctx str tries to parse and expand macro of the given string which should come from the TXT record of a domain-name as the sender policy of this domain-name.